==> battlefy_toolkit-Slate-1.1.2.tar.gz: battlefy_toolkit-Slate-1.1.2/src/battlefy_toolkit/org_lists/splatoon_orgs.py <==

ORG_SLUGS = list({
    "lsi",
    "splatoon-sea-level-up-tournament-organization",
    "torneo-star-oni",
    "splatcol",
    "shadow-sirens",
    "extrafest",
    "vroom-vroom-veemo",
    "area-cup",
    "inkling-performance-labs",
    "notorious-network-community-league",
    "splashdown-saturdays",
    "tbd-thursdays",
    "sitback-saturdays",
    "boilermaker-booyah",
    "ci-studios",
    "altaira",
    "technorganic-esport-league",
    "inkloning",
    "off-the-dial",
    "swift-second-saturdays",
    "küki-tournaments",
    "deca-tower",
    "fresh-start-cup",
    "casual-friday",
    "circuit-down-under",
    "headspace-horoscopes",
    "aygi-gaming",
    "squid-spawning-grounds",
    "woomy-games-inc",
    "splatendo-competitive™",
    "gamesetmatch",
    "callisto",
    "eki",
    "nebula-splatoon-2",
    "xtreme-tourneys",
    "good-guys-win",
    "asquidmin",
    "armorless-adventures",
    "splatoontbds",
    "project-dorado",
    "jerrys-crown-cup",
    "ranchos-royale",
    "splatoon-amateur-circuit",
    # "murfy",
    "sleepy-cafe",
    "rng-bostoffice-remake",
    "coop-wiiu-competitive",
    "dynamic-ink-testing-chamber",
    "bear-industries",
    "splatoonvod-tournaments",
    "dyn",
    "dual-ink",
    "smash-online-global",
    "squid-south",
    "shadow-clan-tournaments",
    "cca-collegiate-cephalopod-association",
    "trireme-squid-games",
    "tripnacity",
    "the-reef",
    "inkopolis-bay",
    "little-squid-league",
    "squid-garden",
    "splatcom",
    "midway-ink-tour",
    "turf-be-told",
    "snowpoke",
    "boo-yah-bros",
    "toadstournaments",
    "camos-clan",
    "torchy-gaming",
    "summer-splat-series",
    "xanadu-tournament-series",
    "squidboards-splatoon-2-community-events",
    "young-ink-association",
    "inktv",
    "splatoon-amino-official",
    "regular-gaming-splat2-2",
    "the-ink-squad",
    "under-the-ink",
    "the-owo-gang",
    "splatoon2",
    "deep-sea-solutions",
})

==> battlefy_toolkit-Slate-1.2.1.tar.gz: battlefy_toolkit-Slate-1.2.1/src/battlefy_toolkit/org_lists/splatoon_orgs.py <==

ORG_SLUGS = list({
    "altaira",
    "area-cup",
    "armorless-adventures",
    "asquidmin",
    "aygi-gaming",
    "bear-industries",
    "boilermaker-booyah",
    "boo-yah-bros",
    "callisto",
    "camos-clan",
    "casual-friday",
    "cca-collegiate-cephalopod-association",
    "ci-studios",
    "circuit-down-under",
    "coop-wiiu-competitive",
    "deca-tower",
    "deep-sea-solutions",
    "dual-ink",
    "dyn",
    "dynamic-ink-testing-chamber",
    "eki",
    "extrafest",
    "fresh-start-cup",
    "gamesetmatch",
    "good-guys-win",
    "headspace-horoscopes",
    "inkling-performance-labs",
    "inkloning",
    "inkopolis-bay",
    "inktv",
    "jerrys-crown-cup",
    "jpgs-questionable-tournaments",
    "küki-tournaments",
    "little-squid-league",
    "lsi",
    "midway-ink-tour",
    "nebula-splatoon-2",
    "notorious-network-community-league",
    "off-the-dial",
    "project-dorado",
    "ranchos-royale",
    "regular-gaming-splat2-2",
    "rng-bostoffice-remake",
    "shadow-clan-tournaments",
    "shadow-sirens",
    "sitback-saturdays",
    "sleepy-cafe",
    "smash-online-global",
    "snowpoke",
    "splashdown-saturdays",
    "splatcol",
    "splatcom",
    "splatendo-competitive™",
    "splatoon-amateur-circuit",
    "splatoon-amino-official",
    "splatoon-sea-level-up-tournament-organization",
    "splatoon2",
    "splatoontbds",
    "splatoonvod-tournaments",
    "squid-garden",
    "squid-junction",
    "squid-south",
    "squid-spawning-grounds",
    "squidboards-splatoon-2-community-events",
    "sue_splat",
    "summer-splat-series",
    "swift-second-saturdays",
    "tbd-thursdays",
    "technorganic-esport-league",
    "the-ink-squad",
    "the-owo-gang",
    "the-reef",
    "toadstournaments",
    "torchy-gaming",
    "torneo-star-oni",
    "tripnacity",
    "trireme-squid-games",
    "turf-be-told",
    "ultimate-splat-championship",
    "under-the-ink",
    "vroom-vroom-veemo",
    "woomy-games-inc",
    "xanadu-tournament-series",
    "xtreme-tourneys",
    "young-ink-association",
})
